@@ -23,6 +23,10 @@
 #  include <stdint.h>
 #endif
 
+#if HAVE_STDBOOL_H
+#  include <stdbool.h>
+#endif
+
 #if HAVE_NETINET_IN_H
 #  include <netinet/in.h>
 #endif
